@@ -601,7 +601,7 @@ int main(int argc, char *argv[]) {
 	if (set.poller_id_exists) {
 		qp += sprintf(qp, " AND host.poller_id=%i", set.poller_id);
 	}
-	qp += sprintf(qp, " ORDER BY id");
+	qp += sprintf(qp, " ORDER BY polling_time DESC");
 
 	result = db_query(&mysql, querybuf);
 	if (set.poller_id == 0) {
